package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicCarouselImage;
import com.bonus.canteen.core.basic.service.IBasicCarouselImageService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 轮播图设置Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "轮播图设置接口")
@RestController
@RequestMapping("/basic_carousel_image")
public class BasicCarouselImageController extends BaseController {
    @Autowired
    private IBasicCarouselImageService basicCarouselImageService;

    /**
     * 查询轮播图设置列表
     */
    @ApiOperation(value = "查询轮播图设置列表")
    //@RequiresPermissions("basic:image:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicCarouselImage basicCarouselImage) {
        startPage();
        List<BasicCarouselImage> list = basicCarouselImageService.selectBasicCarouselImageList(basicCarouselImage);
        return getDataTable(list);
    }

    /**
     * 导出轮播图设置列表
     */
    @ApiOperation(value = "导出轮播图设置列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:image:export")
    @SysLog(title = "轮播图设置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出轮播图设置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicCarouselImage basicCarouselImage) {
        List<BasicCarouselImage> list = basicCarouselImageService.selectBasicCarouselImageList(basicCarouselImage);
        ExcelUtil<BasicCarouselImage> util = new ExcelUtil<BasicCarouselImage>(BasicCarouselImage.class);
        util.exportExcel(response, list, "轮播图设置数据");
    }

    /**
     * 获取轮播图设置详细信息
     */
    @ApiOperation(value = "获取轮播图设置详细信息")
    //@RequiresPermissions("basic:image:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(basicCarouselImageService.selectBasicCarouselImageById(id));
    }

    /**
     * 新增轮播图设置
     */
    @ApiOperation(value = "新增轮播图设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:image:add")
    @SysLog(title = "轮播图设置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增轮播图设置")
    @PostMapping
    public AjaxResult add(@RequestBody BasicCarouselImage basicCarouselImage) {
        try {
            return toAjax(basicCarouselImageService.insertBasicCarouselImage(basicCarouselImage));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改轮播图设置
     */
    @ApiOperation(value = "修改轮播图设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:image:edit")
    @SysLog(title = "轮播图设置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改轮播图设置")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicCarouselImage basicCarouselImage) {
        try {
            return toAjax(basicCarouselImageService.updateBasicCarouselImage(basicCarouselImage));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除轮播图设置
     */
    @ApiOperation(value = "删除轮播图设置")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:image:remove")
    @SysLog(title = "轮播图设置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除轮播图设置")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(basicCarouselImageService.deleteBasicCarouselImageByIds(ids));
    }
}
